@@ -114,7 +114,11 @@ fu_hid_device_parse_descriptors(FuHidDevice *self, GError **error)
 		g_autoptr(FuFirmware) descriptor = fu_hid_descriptor_new();
 		g_autofree gchar *title = g_strdup_printf("HidDescriptor:0x%x", i);
 		fu_dump_bytes(G_LOG_DOMAIN, title, fw);
-		if (!fu_firmware_parse_bytes(descriptor, fw, 0x0, FWUPD_INSTALL_FLAG_NONE, error))
+		if (!fu_firmware_parse_bytes(descriptor,
+					     fw,
+					     0x0,
+					     FU_FIRMWARE_PARSE_FLAG_NONE,
+					     error))
 			return NULL;
 		g_ptr_array_add(descriptors, g_steal_pointer(&descriptor));
 	}
@@ -149,6 +153,39 @@ fu_hid_device_autodetect_eps(FuHidDevice *self, FuUsbInterface *iface, GError **
 	return TRUE;
 }
 
+static gboolean
+fu_hid_device_setup(FuDevice *device, GError **error)
+{
+	FuHidDevice *self = FU_HID_DEVICE(device);
+
+	/* FuUsbDevice->setup */
+	if (!FU_DEVICE_CLASS(fu_hid_device_parent_class)->setup(device, error))
+		return FALSE;
+
+	/* best effort, from HID */
+	if (fu_device_get_vendor(device) == NULL) {
+		g_autofree gchar *manufacturer =
+		    fu_udev_device_read_sysfs(FU_UDEV_DEVICE(self),
+					      "manufacturer",
+					      FU_UDEV_DEVICE_ATTR_READ_TIMEOUT_DEFAULT,
+					      NULL);
+		if (manufacturer != NULL)
+			fu_device_set_vendor(device, manufacturer);
+	}
+	if (fu_device_get_name(device) == NULL) {
+		g_autofree gchar *product =
+		    fu_udev_device_read_sysfs(FU_UDEV_DEVICE(self),
+					      "product",
+					      FU_UDEV_DEVICE_ATTR_READ_TIMEOUT_DEFAULT,
+					      NULL);
+		if (product != NULL)
+			fu_device_set_name(device, product);
+	}
+
+	/* success */
+	return TRUE;
+}
+
 static gboolean
 fu_hid_device_open(FuDevice *device, GError **error)
 {
@@ -658,6 +695,7 @@ fu_hid_device_class_init(FuHidDeviceClass *klass)
 	object_class->get_property = fu_hid_device_get_property;
 	object_class->set_property = fu_hid_device_set_property;
 	device_class->open = fu_hid_device_open;
+	device_class->setup = fu_hid_device_setup;
 	device_class->close = fu_hid_device_close;
 	device_class->to_string = fu_hid_device_to_string;
 
