@@ -1388,7 +1388,7 @@ static FuFirmware *
 fu_dfu_device_prepare_firmware(FuDevice *device,
 			       GInputStream *stream,
 			       FuProgress *progress,
-			       FwupdInstallFlags flags,
+			       FuFirmwareParseFlags flags,
 			       GError **error)
 {
 	return fu_firmware_new_from_gtypes(stream,
@@ -1415,7 +1415,7 @@ fu_dfu_device_write_firmware(FuDevice *device,
 	/* open it */
 	if (!fu_dfu_device_refresh_and_clear(self, error))
 		return FALSE;
-	if (flags & FWUPD_INSTALL_FLAG_IGNORE_VID_PID) {
+	if (flags & FU_FIRMWARE_PARSE_FLAG_IGNORE_VID_PID) {
 		transfer_flags |= DFU_TARGET_TRANSFER_FLAG_WILDCARD_VID;
 		transfer_flags |= DFU_TARGET_TRANSFER_FLAG_WILDCARD_PID;
 	}
@@ -1466,6 +1466,7 @@ static void
 fu_dfu_device_set_progress(FuDevice *self, FuProgress *progress)
 {
 	fu_progress_set_id(progress, G_STRLOC);
+	fu_progress_add_step(progress, FWUPD_STATUS_DECOMPRESSING, 0, "prepare-fw");
 	fu_progress_add_step(progress, FWUPD_STATUS_DEVICE_RESTART, 1, "detach");
 	fu_progress_add_step(progress, FWUPD_STATUS_DEVICE_WRITE, 88, "write");
 	fu_progress_add_step(progress, FWUPD_STATUS_DEVICE_RESTART, 1, "attach");
