@@ -378,7 +378,7 @@ fu_test_redfish_devices_func(gconstpointer user_data)
 	g_assert_cmpint(fu_device_get_version_format(dev), ==, FWUPD_VERSION_FORMAT_PAIR);
 	g_assert_cmpint(fu_device_get_version_build_date(dev), ==, 1552608000);
 	g_assert_true(fu_device_has_flag(dev, FWUPD_DEVICE_FLAG_UPDATABLE));
-	g_assert_true(fu_device_has_icon(dev, "network-wired"));
+	g_assert_true(fu_device_has_icon(dev, FU_DEVICE_ICON_NETWORK_WIRED));
 	g_assert_true(fu_device_has_protocol(dev, "org.dmtf.redfish"));
 	g_assert_true(fu_device_has_guid(dev, "fee82a67-6ce2-4625-9f44-237ad2402c28"));
 	g_assert_true(fu_device_has_guid(dev, "a6d3294e-37e5-50aa-ae2f-c0c457af16f3"));
